### GWpy example request

Please consider the example description below for inclusion in the
GWpy online documentation:

---

<!--
Please fill out the sections below, replacing uppercase
variables with something appropriate.

If you would like to see an example of something, but don't know how
it should look, please feel free to remove any incomplete placeholders
(e.g. the EXAMPLE_CODE block).
-->

#### EXAMPLE_TITLE

EXAMPLE_DESCRIPTION

Example code:

```python
EXAMPLE_CODE
```

Citations/references:

- EXAMPLE_CITATION_ONE
- EXAMPLE_CITATION_TWO
